# CHANGELOG

<!-- version list -->

## v1.8.0 (2025-06-19)

### Features

- New release file
  ([`7e02ce4`](https://github.com/nabinelnino/new-package/commit/7e02ce4d515514c8afda274146c3ceac46534750))


## v1.7.0 (2025-06-19)

### Bug Fixes

- Fixing main file
  ([`d1080e8`](https://github.com/nabinelnino/new-package/commit/d1080e8244da13d79f58ea77dabed18c5805b6a8))

### Features

- Data column function added
  ([`d3a9412`](https://github.com/nabinelnino/new-package/commit/d3a94123e7445c238bc5a15c9ed793e7fc26b346))

- New release added
  ([`5ca96d0`](https://github.com/nabinelnino/new-package/commit/5ca96d01b388cd5cd2ab7baa3e4e57c8e162bbfa))


## v1.6.1 (2025-06-18)


## v1.6.0 (2025-06-18)

### Features

- Linting policies updated
  ([`ab189b0`](https://github.com/nabinelnino/new-package/commit/ab189b03ba953eb86e59a0e9450a7fdf4a771106))


## v1.5.0 (2025-06-18)

### Features

- New dev section added
  ([`37d4798`](https://github.com/nabinelnino/new-package/commit/37d4798a64a01b441415834c45404d5c4e9c657d))


## v1.4.0 (2025-06-18)


## v1.3.0 (2025-06-05)


## v1.2.0 (2025-06-05)


## v1.1.0 (2025-06-05)

### Features

- Pyproject file fixed
  ([`a99f218`](https://github.com/nabinelnino/new-package/commit/a99f21822e73552f5798ed4870430a9f364e2b6c))


## v1.0.0 (2025-06-04)

- Initial Release
